from setuptools import setup, find_packages

setup(
    name = "RTUweatherBot",
    version = "1.0",
    description = "Telegram bot about the weather",
    url = "https://github.com/devilishgrapefruit/RTUweatherBot",
    packages = find_packages()
)